@@ -4,14 +4,11 @@
 __author__ = "Gregory Sitnin <sitnin@gmail.com>"
 __copyright__ = "WWPass Corporation, 2011"
 
-import sys
-import logging
-import pprint
 
 def all():
     return {
         "month_ru": month_ru,
-        "plural_date_ru": plural_date_ru,
+        "hum_month_ru": hum_month_ru,
     }
 
 def month_ru(month):
@@ -24,4 +21,3 @@ def hum_month_ru(dt, year=False):
     if year:
         result += " %d года"%dt.year
     return result
-
